bayespy.inference.vmp.nodes.gaussian.GaussianWishartDistribution.random
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartDistribution.random